# SportScraper

ESPN.com is a great site for gathering statistics about sports teams at both the college and major league level. This repository provides an easy to use interface for pulling data from the ESPN website. 


## Disclaimer
This library is for educational purposes only. Webscraping of publicly available data was ruled legal by The Ninth Circuit Court of Appeals (http://cdn.ca9.uscourts.gov/datastore/opinions/2019/09/09/17-16783.pdf).

## Development

## Contributors
